@@ -9,6 +9,7 @@ import multiprocessing
 from time import time, sleep
 from functools import wraps
 from setproctitle import setproctitle
+import kuyruk
 from kuyruk import importer
 from kuyruk.queue import Queue
 from kuyruk.channel import LazyChannel
@@ -341,6 +342,7 @@ class Worker(KuyrukProcess):
             'uptime': self.uptime,
             'pid': os.getpid(),
             'ppid': os.getppid(),
+            'version': kuyruk.__version__,
             'current_task': current_task,
             'current_args': self.current_args,
             'current_kwargs': self.current_kwargs,
